@@ -23,9 +23,9 @@
 #  include "config.h"
 #endif
 
+#include <errno.h>
 #include <stdlib.h>
 #include <string.h>
-#include <errno.h>
 
 #include "xalloc.h"
 
@@ -37,12 +37,13 @@ void temp_dir_setup (void)
 {
 	temp_dir = xstrdup ("libpipeline.XXXXXX");
 	if (mkdtemp (temp_dir) == NULL)
-		fail ("mkdtemp failed: %s", strerror (errno));
+		ck_abort_msg ("mkdtemp failed: %s", strerror (errno));
 }
 
 void temp_dir_teardown (void)
 {
-	pipeline_run (pipeline_new_command_args ("rm", "-rf", temp_dir, NULL));
+	pipeline_run (
+	        pipeline_new_command_args ("rm", "-rf", temp_dir, (void *) 0));
 	free (temp_dir);
 	temp_dir = NULL;
 }
